@@ -369,7 +369,7 @@ goa_client_new_cb (GObject      *object,
       g_set_error (&data->error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED,
-                   _("Failed to initialise a GOA client"));
+                   _("Failed to initialize a GOA client"));
       g_main_loop_quit (data->loop);
       return;
     }
@@ -877,23 +877,20 @@ show_account (GoaProvider         *provider,
               GoaClient           *client,
               GoaObject           *object,
               GtkBox              *vbox,
-              GtkGrid             *left,
-              GtkGrid             *right)
+              GtkGrid             *grid,
+              G_GNUC_UNUSED GtkGrid *dummy)
 {
   EditData *data = NULL;
   GtkWidget *params_button = NULL;
   GtkWidget *details_button = NULL;
   GtkWidget *button_box = NULL;
+  gint row;
 
-  /* Chain up */
-  GOA_PROVIDER_CLASS (goa_telepathy_provider_parent_class)->show_account (provider,
-                                                                          client,
-                                                                          object,
-                                                                          vbox,
-                                                                          left,
-                                                                          right);
+  row = 0;
 
-  goa_util_add_row_switch_from_keyfile_with_blurb (left, right, object,
+  goa_util_add_account_info (grid, row++, object);
+
+  goa_util_add_row_switch_from_keyfile_with_blurb (grid, row++, object,
                                                    _("Use for"),
                                                    "chat-disabled",
                                                    _("C_hat"));
@@ -915,7 +912,7 @@ show_account (GoaProvider         *provider,
   gtk_box_pack_start (GTK_BOX (button_box), details_button,
       FALSE, FALSE, 0);
 
-  goa_util_add_row_widget (left, right, NULL, button_box);
+  goa_util_add_row_widget (grid, row++, NULL, button_box);
 
   edit_data_unref (data);
 }
@@ -1030,12 +1027,41 @@ goa_telepathy_provider_finalize (GObject *object)
   (G_OBJECT_CLASS (goa_telepathy_provider_parent_class)->finalize) (object);
 }
 
+static void
+initialize_client_factory (void)
+{
+  TpSimpleClientFactory *factory;
+  TpAccountManager *account_manager;
+  GQuark account_features[] = {
+      TP_ACCOUNT_FEATURE_STORAGE,
+      TP_ACCOUNT_FEATURE_CONNECTION,
+      0};
+  GQuark connection_features[] = {
+      TP_CONNECTION_FEATURE_AVATAR_REQUIREMENTS,
+      TP_CONNECTION_FEATURE_CONTACT_INFO,
+      0};
+
+  /* We make sure that new instances of Telepathy objects will have all
+   * the features we need. */
+  factory = tp_simple_client_factory_new (NULL);
+  tp_simple_client_factory_add_account_features (factory, account_features);
+  tp_simple_client_factory_add_connection_features (factory, connection_features);
+
+  account_manager = tp_account_manager_new_with_factory (factory);
+  tp_account_manager_set_default (account_manager);
+
+  g_object_unref (account_manager);
+  g_object_unref (factory);
+}
+
 static void
 goa_telepathy_provider_class_init (GoaTelepathyProviderClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GoaProviderClass *provider_class = GOA_PROVIDER_CLASS (klass);
 
+  initialize_client_factory ();
+
   object_class->constructed  = goa_telepathy_provider_constructed;
   object_class->finalize     = goa_telepathy_provider_finalize;
   object_class->get_property = goa_telepathy_provider_get_property;
